ci

Function ci 

pub fn ci() -> Result<()>
Executes a sequence of typical Continuous Integration (CI) tasks.

This function will perform the following CI tasks in order:

  1. Format check using cargo fmt.
  2. Linting using cargo clippy.
  3. Run tests using cargo test.
  4. Run documentation tests using cargo test --doc.

The specific settings for these tasks, such as whether to use the nightly compiler or to enable all Clippy lints, are determined by the default configuration of the CI struct.

Errors

This function will return an error if any of the CI tasks fail to execute. The specific task that failed will be included in the error message to aid in debugging.